#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://www.diracvideo.org/download/schroedinger
# last revised       : 20.02.2012

softname='schroedinger'
softversion='1.0.11'
packageversion='72.1'

arch='i486'
cpu='i686'

set -e 

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://www.diracvideo.org/download/schroedinger/$softname-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
            |-----handy-ruler------------------------------------------------------|
schroedinger: schroedinger (Library for (en)decoding video in the Dirac format)
schroedinger:
schroedinger: Library for decoding and encoding video in the Dirac format.
schroedinger: It is implemented in ANSI C and optimized through the us of liboil.
schroedinger: libschro is written as a collaboration between the BBC Research and
schroedinger: Development, David Schleef and Fluendo.
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./autogen.sh
  
./configure \
    --prefix=/usr \
    --libdir=/usr/lib \
    --sysconfdir=/etc \
    --localstatedir=/var \
    --mandir=/usr/man \
    --disable-debug \
    --disable-static \
    --with-html-dir=/usr/doc/$softname/ \
    --build=$arch-slackware-linux  

make
make install DESTDIR=$dest

# api docs
mkdir -p $dest/usr/doc/$softname-$softversion
rm $dest/usr/doc/$softname/schroedinger/index.sgml
tar cjf $dest/usr/doc/$softname/schroedinger_html.tar.bz2 \
     -C $dest/usr/doc/$softname schroedinger
cp $dest/usr/doc/$softname/schroedinger_html.tar.bz2 $dest/usr/doc/$softname-$softversion/
rm -fr $dest/usr/doc/$softname

cp -a \
   AUTHORS COPYING* NEWS TODO \
   $dest/usr/doc/$softname-$softversion
        
# strip executables
(
  find $dest | xargs -r file | grep "executable\|shared object" | grep ELF | cut -f 1 -d : | xargs -r strip --strip-unneeded
  find $dest| xargs -r file | grep "current ar archive" | cut -f 1 -d : | xargs -r strip -g
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "cxxlibs,gcc,orc" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/l/schroedinger/source/build-schroedinger.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
